#!/bin/bash
###############################################################################
#
# Bash Remediation Script for Profile for ANSSI DAT-NT28 Average (Intermediate) Level
#
# Profile Description:
# This profile contains items for GNU/Linux installations already protected by multiple higher level security stacks.
#
# Profile ID:  anssi_np_nt28_average
# Benchmark ID:  UBUNTU-TRUSTY
# Benchmark Version:  0.1.39
# XCCDF Version:  1.1
#
# This file was generated by OpenSCAP 1.3.2 using:
# $ oscap xccdf generate fix --profile anssi_np_nt28_average --fix-type bash xccdf-file.xml
#
# This Bash Remediation Script is generated from an OpenSCAP profile without preliminary evaluation.
# It attempts to fix every selected rule, even if the system is already compliant.
#
# How to apply this Bash Remediation Script:
# $ sudo ./remediation-script.sh
#
###############################################################################

###############################################################################
# BEGIN fix (1 / 32) for 'package_nis_removed'
###############################################################################
(>&2 echo "Remediating rule 1/32: 'package_nis_removed'")
# CAUTION: This remediation script will remove nis
#	   from the system, and may remove any packages
#	   that depend on nis. Execute this
#	   remediation AFTER testing on a non-production
#	   system!

apt-get remove --purge nis

# END fix for 'package_nis_removed'

###############################################################################
# BEGIN fix (2 / 32) for 'package_inetutils-telnetd_removed'
###############################################################################
(>&2 echo "Remediating rule 2/32: 'package_inetutils-telnetd_removed'")
# CAUTION: This remediation script will remove inetutils-telnetd
#	   from the system, and may remove any packages
#	   that depend on inetutils-telnetd. Execute this
#	   remediation AFTER testing on a non-production
#	   system!

apt-get remove --purge inetutils-telnetd

# END fix for 'package_inetutils-telnetd_removed'

###############################################################################
# BEGIN fix (3 / 32) for 'package_ntpdate_removed'
###############################################################################
(>&2 echo "Remediating rule 3/32: 'package_ntpdate_removed'")
# CAUTION: This remediation script will remove ntpdate
#	   from the system, and may remove any packages
#	   that depend on ntpdate. Execute this
#	   remediation AFTER testing on a non-production
#	   system!

apt-get remove --purge ntpdate

# END fix for 'package_ntpdate_removed'

###############################################################################
# BEGIN fix (4 / 32) for 'package_telnetd-ssl_removed'
###############################################################################
(>&2 echo "Remediating rule 4/32: 'package_telnetd-ssl_removed'")
# CAUTION: This remediation script will remove telnetd-ssl
#	   from the system, and may remove any packages
#	   that depend on telnetd-ssl. Execute this
#	   remediation AFTER testing on a non-production
#	   system!

apt-get remove --purge telnetd-ssl

# END fix for 'package_telnetd-ssl_removed'

###############################################################################
# BEGIN fix (5 / 32) for 'package_telnetd_removed'
###############################################################################
(>&2 echo "Remediating rule 5/32: 'package_telnetd_removed'")
# CAUTION: This remediation script will remove telnetd
#	   from the system, and may remove any packages
#	   that depend on telnetd. Execute this
#	   remediation AFTER testing on a non-production
#	   system!

apt-get remove --purge telnetd

# END fix for 'package_telnetd_removed'

###############################################################################
# BEGIN fix (6 / 32) for 'package_ntp_installed'
###############################################################################
(>&2 echo "Remediating rule 6/32: 'package_ntp_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_ntp_installed' IS MISSING!")

# END fix for 'package_ntp_installed'

###############################################################################
# BEGIN fix (7 / 32) for 'sshd_allow_only_protocol2'
###############################################################################
(>&2 echo "Remediating rule 7/32: 'sshd_allow_only_protocol2'")
(>&2 echo "FIX FOR THIS RULE 'sshd_allow_only_protocol2' IS MISSING!")

# END fix for 'sshd_allow_only_protocol2'

###############################################################################
# BEGIN fix (8 / 32) for 'sshd_disable_empty_passwords'
###############################################################################
(>&2 echo "Remediating rule 8/32: 'sshd_disable_empty_passwords'")
(>&2 echo "FIX FOR THIS RULE 'sshd_disable_empty_passwords' IS MISSING!")

# END fix for 'sshd_disable_empty_passwords'

###############################################################################
# BEGIN fix (9 / 32) for 'sshd_set_idle_timeout'
###############################################################################
(>&2 echo "Remediating rule 9/32: 'sshd_set_idle_timeout'")
(>&2 echo "FIX FOR THIS RULE 'sshd_set_idle_timeout' IS MISSING!")

# END fix for 'sshd_set_idle_timeout'

###############################################################################
# BEGIN fix (10 / 32) for 'sshd_set_keepalive'
###############################################################################
(>&2 echo "Remediating rule 10/32: 'sshd_set_keepalive'")
(>&2 echo "FIX FOR THIS RULE 'sshd_set_keepalive' IS MISSING!")

# END fix for 'sshd_set_keepalive'

###############################################################################
# BEGIN fix (11 / 32) for 'sshd_disable_root_login'
###############################################################################
(>&2 echo "Remediating rule 11/32: 'sshd_disable_root_login'")
(>&2 echo "FIX FOR THIS RULE 'sshd_disable_root_login' IS MISSING!")

# END fix for 'sshd_disable_root_login'

###############################################################################
# BEGIN fix (12 / 32) for 'apt_conf_disallow_unauthenticated'
###############################################################################
(>&2 echo "Remediating rule 12/32: 'apt_conf_disallow_unauthenticated'")
(>&2 echo "FIX FOR THIS RULE 'apt_conf_disallow_unauthenticated' IS MISSING!")

# END fix for 'apt_conf_disallow_unauthenticated'

###############################################################################
# BEGIN fix (13 / 32) for 'sudo_remove_no_authenticate'
###############################################################################
(>&2 echo "Remediating rule 13/32: 'sudo_remove_no_authenticate'")
(>&2 echo "FIX FOR THIS RULE 'sudo_remove_no_authenticate' IS MISSING!")

# END fix for 'sudo_remove_no_authenticate'

###############################################################################
# BEGIN fix (14 / 32) for 'sudo_remove_nopasswd'
###############################################################################
(>&2 echo "Remediating rule 14/32: 'sudo_remove_nopasswd'")
(>&2 echo "FIX FOR THIS RULE 'sudo_remove_nopasswd' IS MISSING!")

# END fix for 'sudo_remove_nopasswd'

###############################################################################
# BEGIN fix (15 / 32) for 'rsyslog_files_groupownership'
###############################################################################
(>&2 echo "Remediating rule 15/32: 'rsyslog_files_groupownership'")
(>&2 echo "FIX FOR THIS RULE 'rsyslog_files_groupownership' IS MISSING!")

# END fix for 'rsyslog_files_groupownership'

###############################################################################
# BEGIN fix (16 / 32) for 'rsyslog_files_ownership'
###############################################################################
(>&2 echo "Remediating rule 16/32: 'rsyslog_files_ownership'")
(>&2 echo "FIX FOR THIS RULE 'rsyslog_files_ownership' IS MISSING!")

# END fix for 'rsyslog_files_ownership'

###############################################################################
# BEGIN fix (17 / 32) for 'rsyslog_files_permissions'
###############################################################################
(>&2 echo "Remediating rule 17/32: 'rsyslog_files_permissions'")
(>&2 echo "FIX FOR THIS RULE 'rsyslog_files_permissions' IS MISSING!")

# END fix for 'rsyslog_files_permissions'

###############################################################################
# BEGIN fix (18 / 32) for 'ensure_logrotate_activated'
###############################################################################
(>&2 echo "Remediating rule 18/32: 'ensure_logrotate_activated'")
(>&2 echo "FIX FOR THIS RULE 'ensure_logrotate_activated' IS MISSING!")

# END fix for 'ensure_logrotate_activated'

###############################################################################
# BEGIN fix (19 / 32) for 'partition_for_home'
###############################################################################
(>&2 echo "Remediating rule 19/32: 'partition_for_home'")
(>&2 echo "FIX FOR THIS RULE 'partition_for_home' IS MISSING!")

# END fix for 'partition_for_home'

###############################################################################
# BEGIN fix (20 / 32) for 'partition_for_var'
###############################################################################
(>&2 echo "Remediating rule 20/32: 'partition_for_var'")
(>&2 echo "FIX FOR THIS RULE 'partition_for_var' IS MISSING!")

# END fix for 'partition_for_var'

###############################################################################
# BEGIN fix (21 / 32) for 'partition_for_tmp'
###############################################################################
(>&2 echo "Remediating rule 21/32: 'partition_for_tmp'")
(>&2 echo "FIX FOR THIS RULE 'partition_for_tmp' IS MISSING!")

# END fix for 'partition_for_tmp'

###############################################################################
# BEGIN fix (22 / 32) for 'partition_for_var_log_audit'
###############################################################################
(>&2 echo "Remediating rule 22/32: 'partition_for_var_log_audit'")
(>&2 echo "FIX FOR THIS RULE 'partition_for_var_log_audit' IS MISSING!")

# END fix for 'partition_for_var_log_audit'

###############################################################################
# BEGIN fix (23 / 32) for 'partition_for_var_log'
###############################################################################
(>&2 echo "Remediating rule 23/32: 'partition_for_var_log'")
(>&2 echo "FIX FOR THIS RULE 'partition_for_var_log' IS MISSING!")

# END fix for 'partition_for_var_log'

###############################################################################
# BEGIN fix (24 / 32) for 'sysctl_fs_protected_hardlinks'
###############################################################################
(>&2 echo "Remediating rule 24/32: 'sysctl_fs_protected_hardlinks'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_fs_protected_hardlinks' IS MISSING!")

# END fix for 'sysctl_fs_protected_hardlinks'

###############################################################################
# BEGIN fix (25 / 32) for 'sysctl_fs_protected_symlinks'
###############################################################################
(>&2 echo "Remediating rule 25/32: 'sysctl_fs_protected_symlinks'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_fs_protected_symlinks' IS MISSING!")

# END fix for 'sysctl_fs_protected_symlinks'

###############################################################################
# BEGIN fix (26 / 32) for 'file_permissions_etc_group'
###############################################################################
(>&2 echo "Remediating rule 26/32: 'file_permissions_etc_group'")
chmod 0644 /etc/group

# END fix for 'file_permissions_etc_group'

###############################################################################
# BEGIN fix (27 / 32) for 'file_permissions_etc_shadow'
###############################################################################
(>&2 echo "Remediating rule 27/32: 'file_permissions_etc_shadow'")
chmod 0640 /etc/shadow

# END fix for 'file_permissions_etc_shadow'

###############################################################################
# BEGIN fix (28 / 32) for 'file_permissions_etc_gshadow'
###############################################################################
(>&2 echo "Remediating rule 28/32: 'file_permissions_etc_gshadow'")
chmod 0640 /etc/gshadow

# END fix for 'file_permissions_etc_gshadow'

###############################################################################
# BEGIN fix (29 / 32) for 'file_permissions_etc_passwd'
###############################################################################
(>&2 echo "Remediating rule 29/32: 'file_permissions_etc_passwd'")
chmod 0644 /etc/passwd

# END fix for 'file_permissions_etc_passwd'

###############################################################################
# BEGIN fix (30 / 32) for 'file_permissions_systemmap'
###############################################################################
(>&2 echo "Remediating rule 30/32: 'file_permissions_systemmap'")
(>&2 echo "FIX FOR THIS RULE 'file_permissions_systemmap' IS MISSING!")

# END fix for 'file_permissions_systemmap'

###############################################################################
# BEGIN fix (31 / 32) for 'sysctl_fs_suid_dumpable'
###############################################################################
(>&2 echo "Remediating rule 31/32: 'sysctl_fs_suid_dumpable'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_fs_suid_dumpable' IS MISSING!")

# END fix for 'sysctl_fs_suid_dumpable'

###############################################################################
# BEGIN fix (32 / 32) for 'sysctl_kernel_randomize_va_space'
###############################################################################
(>&2 echo "Remediating rule 32/32: 'sysctl_kernel_randomize_va_space'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_randomize_va_space' IS MISSING!")

# END fix for 'sysctl_kernel_randomize_va_space'

